require "ZuoraHpm/version"

module ZuoraHpm
  class Error < StandardError; end

  #default values
  @locale = 'en'
  @param_supportedTypes = "AmericanExpress,JCB,Visa,MasterCard,Discover,Dankort"
  @style= "overlay"
  @submitEnabled = true
  @url = 'https://rest.apisandbox.zuora.com/v1/rsa-signatures'
  @uri = 'https://apisandbox.zuora.com/apps/PublicHostedPageLite.do'

  def self.set_username=(username)
    @username = username
  end

  def self.get_username
    return @username
  end

  def self.set_paymentGateway(paymentG)
    @paymentGateway = paymentG
  end

  def self.set_locale(locale)
    @locale= locale
  end

  def self.set_param_supportedTypes(supportedTypes)
    @param_supportedTypes = supportedTypes
  end

  def self.set_endpoint(url)
    if((url == 'https://rest.zuora.com/v1/rsa-signatures') || (url == 'https://rest.eu.zuora.com/v1/rsa-signatures') || (url == 'https://rest.apisandbox.zuora.com/v1/rsa-signatures') || (url=='https://rest.sandbox.eu.zuora.com/v1/rsa-signatures'))
      @url = url
    else
      puts 'Invalid z_environment. Go to https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/LA_Hosted_Payment_Pages/B_Payment_Pages_2.0/F_Generate_the_Digital_Signature_for_Payment_Pages_2.0 to see valid urls.'
      @url = 'invalid'
    end
  end

  def self.get_endpoint
    return @url
  end

  def self.get_uri
    if((@url == 'https://rest.zuora.com/v1/rsa-signatures') || (@url == 'https://rest.eu.zuora.com/v1/rsa-signatures'))
      @uri = 'https://www.zuora.com/apps/PublicHostedPageLite.do'
    elsif((@url == 'https://rest.apisandbox.zuora.com/v1/rsa-signatures') || (@url=='https://rest.sandbox.eu.zuora.com/v1/rsa-signatures'))
      @uri = 'https://apisandbox.zuora.com/apps/PublicHostedPageLite.do'
    else
      @uri = 'invalid'
    end
  end

  def self.set_style=(style)
    if(style == 'inline_in')
      @style = "inline"
      @submitEnabled = true
    elsif(style == 'inline_out')
      @style = "inline"
      @submitEnabled = false
    elsif(style == 'overlay')
      @style = "overlay"
      @submitEnabled = true
    else
      @style = 'invalid'
    end
  end

  def self.get_style
    return @style
  end

  def self.set_password=(password)
    @password = password
  end


  def self.get_rsa_signature(page_id)
    require 'uri'
    require 'net/http'
    require 'json'
    @page_id = page_id
    url = URI(@url)
    the_request_url =  @uri
    http = Net::HTTP.new(url.host, url.port)
    http.use_ssl = true
    http.verify_mode = OpenSSL::SSL::VERIFY_NONE
    request = Net::HTTP::Post.new(url)
    request["content-type"] = 'application/json'
    request["apiAccessKeyId"] = @username
    request["apiSecretAccessKey"] = @password
    request.body = "{\n    \"method\": \"POST\", \n    \"pageId\": \"#{page_id}\", \n    \"uri\": \"#{the_request_url}\"\n}"

    response = http.request(request)
    @data = JSON.parse(response.body)
    set_data
    return @data
  end

  def self.set_data
    @signature = @data["signature"]
    @token = @data["token"]
    @tenant_id = @data["tenantId"]
    @key = @data["key"]
    @success = @data["success"]
  end

  def self.get_signature
    return @signature
  end

  def self.get_token
    return @token
  end

  def self.get_tenant_id
    return @tenant_id
  end

  def self.get_key
    return @key
  end

  def self.get_success
    return @success
  end

  def self.get_params(style)
    require 'json'
      @params = {
          tenantId: "#{@tenant_id}",
          id: "#{@page_id}",
          token: "#{@token}",
          signature: "#{@signature}",
          style: "#{@style}",
          key: "#{@key}",
          submitEnabled: "#{@submitEnabled}",
          locale: "#{@locale}",
          param_supportedTypes: "#{@param_supportedTypes}",
          url: "#{@uri}",
          paymentGateway: "#{@paymentGateway}"
      }
    return @params
  end


end
